==> vite-plugin-proxy-0.3.1.tgz: package/src/middlewares/proxy.js <==
import parseurl from 'parseurl'
import * as proxy from '../proxy.js'
import finalhandler from 'finalhandler'
import { HttpError } from 'http-errors'
import logger from '../logger.js'
import { createPath } from '../http.js'

export default function ({ urls, secure }) {
  return async (req, res, next) => {
    if (req.headers['proxied-by-ox-proxy']) return next()

    const { path } = parseurl(req)
    for (const [condition, config] of urls) {
      const { hostname, protocol, port, changeOrigin = false } = config
      const isRegExp = condition instanceof RegExp
      const shouldHandle = isRegExp ? condition.test(path) : path.startsWith(condition)
      if (shouldHandle) {
        try {
          const newPath = createPath(path, config)
          const headers = {}
          // forwarded request falls back to http 1.x, so we must have a valid host header
          if (changeOrigin === true) {
            headers.host = port ? `${hostname}:${port}` : hostname
          } else {
            headers.host = req.headers[':authority'] || req.headers.host
          }
          logger.info(`Proxy ${path} to ${protocol}//${hostname}:${port}${newPath}`)
          logger.trace(`Set headers for ${path}: ${JSON.stringify(headers)}`)
          await proxy.web(req, res, { hostname, protocol, port, secure, path: newPath, headers })
          logger.debug(`Proxied ${path} to ${protocol}//${hostname}:${port}${path}`)
          return
        } catch (err) {
          const handle = finalhandler(req, res)
          if (err instanceof HttpError) {
            logger.warn(`Could not proxy ${path}`)
            return handle(err)
          }
          logger.error(err)
          return handle()
        }
      }
    }

    next()
  }
}

==> vite-plugin-proxy-0.4.2.tgz: package/src/middlewares/proxy.js <==
import parseurl from 'parseurl'
import * as proxy from '../proxy.js'
import finalhandler from 'finalhandler'
import { HttpError } from 'http-errors'
import logger from '../logger.js'
import { createPath } from '../http.js'

export default function ({ urls }) {
  return async (req, res, next) => {
    if (req.headers['proxied-by-ox-proxy']) return next()

    const { path } = parseurl(req)
    for (const [condition, config] of urls) {
      const { hostname, protocol, port, changeOrigin = false, secure } = config
      const isRegExp = condition instanceof RegExp
      const shouldHandle = isRegExp ? condition.test(path) : path.startsWith(condition)
      if (shouldHandle) {
        try {
          const newPath = createPath(path, config)
          const headers = {}
          // forwarded request falls back to http 1.x, so we must have a valid host header
          if (changeOrigin === true) {
            headers.host = port ? `${hostname}:${port}` : hostname
          } else {
            headers.host = req.headers[':authority'] || req.headers.host
          }
          logger.info(`Proxy ${path} to ${protocol}//${hostname}:${port}${newPath}`)
          logger.trace(`Set headers for ${path}: ${JSON.stringify(headers)}`)
          await proxy.web(req, res, { hostname, protocol, port, secure, path: newPath, headers })
          logger.debug(`Proxied ${path} to ${protocol}//${hostname}:${port}${path}`)
          return
        } catch (err) {
          const handle = finalhandler(req, res)
          if (err instanceof HttpError) {
            logger.warn(`Could not proxy ${path}`)
            return handle(err)
          }
          logger.error(err)
          return handle()
        }
      }
    }

    next()
  }
}
